@@ -10,7 +10,7 @@ from samtranslator.model.iam import IAMRolePolicies
 class PullEventSource(ResourceMacro):
     """Base class for pull event sources for SAM Functions.
 
-    The pull events are Kinesis Streams, DynamoDB Streams, and SQS Queues. All of these correspond to an
+    The pull events are Kinesis Streams, DynamoDB Streams, Kafka Streams and SQS Queues. All of these correspond to an
     EventSourceMapping in Lambda, and require that the execution role be given to Kinesis Streams, DynamoDB
     Streams, or SQS Queues, respectively.
 
@@ -30,6 +30,7 @@ class PullEventSource(ResourceMacro):
         "MaximumRecordAgeInSeconds": PropertyType(False, is_type(int)),
         "DestinationConfig": PropertyType(False, is_type(dict)),
         "ParallelizationFactor": PropertyType(False, is_type(int)),
+        "Topics": PropertyType(False, is_type(list)),
     }
 
     def get_policy_arn(self):
@@ -61,11 +62,11 @@ class PullEventSource(ResourceMacro):
 
         if not self.Stream and not self.Queue:
             raise InvalidEventException(
-                self.relative_id, "No Queue (for SQS) or Stream (for Kinesis or DynamoDB) provided."
+                self.relative_id, "No Queue (for SQS) or Stream (for Kinesis, DynamoDB or MSK) provided."
             )
 
         if self.Stream and not self.StartingPosition:
-            raise InvalidEventException(self.relative_id, "StartingPosition is required for Kinesis and DynamoDB.")
+            raise InvalidEventException(self.relative_id, "StartingPosition is required for Kinesis, DynamoDB and MSK.")
 
         lambda_eventsourcemapping.FunctionName = function_name_or_arn
         lambda_eventsourcemapping.EventSourceArn = self.Stream or self.Queue
@@ -77,6 +78,7 @@ class PullEventSource(ResourceMacro):
         lambda_eventsourcemapping.BisectBatchOnFunctionError = self.BisectBatchOnFunctionError
         lambda_eventsourcemapping.MaximumRecordAgeInSeconds = self.MaximumRecordAgeInSeconds
         lambda_eventsourcemapping.ParallelizationFactor = self.ParallelizationFactor
+        lambda_eventsourcemapping.Topics = self.Topics
 
         destination_config_policy = None
         if self.DestinationConfig:
@@ -85,6 +87,8 @@ class PullEventSource(ResourceMacro):
 
             # SAM attaches the policies for SQS or SNS only if 'Type' is given
             if destination_type:
+                # delete this field as its used internally for SAM to determine the policy
+                del self.DestinationConfig["OnFailure"]["Type"]
                 # the values 'SQS' and 'SNS' are allowed. No intrinsics are allowed
                 if destination_type not in ["SQS", "SNS"]:
                     raise InvalidEventException(self.logical_id, "The only valid values for 'Type' are 'SQS' and 'SNS'")
@@ -102,7 +106,6 @@ class PullEventSource(ResourceMacro):
                     destination_config_policy = IAMRolePolicies().sns_publish_role_policy(
                         sns_topic_arn, self.logical_id
                     )
-
             lambda_eventsourcemapping.DestinationConfig = self.DestinationConfig
 
         if "Condition" in function.resource_attributes:
@@ -158,3 +161,12 @@ class SQS(PullEventSource):
 
     def get_policy_arn(self):
         return ArnGenerator.generate_aws_managed_policy_arn("service-role/AWSLambdaSQSQueueExecutionRole")
+
+
+class MSK(PullEventSource):
+    """MSK event source."""
+
+    resource_type = "MSK"
+
+    def get_policy_arn(self):
+        return ArnGenerator.generate_aws_managed_policy_arn("service-role/AWSLambdaMSKExecutionRole")
